==> hive-v2.3.0-sources.jar: org/elastos/hive/ScriptRunner.java <==
package org.elastos.hive;

import com.fasterxml.jackson.databind.JsonNode;

import org.elastos.hive.exception.HiveException;
import org.elastos.hive.service.ScriptingInvocationService;
import org.elastos.hive.vault.scripting.ScriptingController;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.CompletionException;

public class ScriptRunner extends ServiceEndpoint implements ScriptingInvocationService {
	private ScriptingController controller;

	public ScriptRunner(AppContext context, String providerAddress) {
		super(context, providerAddress);
		this.controller = new ScriptingController(this);
	}

	@Override
	public <T> CompletableFuture<T> callScript(String name,
											JsonNode params,
											String targetDid,
											String targetAppDid,
											Class<T> resultType) {

		return CompletableFuture.supplyAsync(()-> {
			if (name == null)
				throw new IllegalArgumentException("Missing script name.");

			//if (params == null)
			//	throw new IllegalArgumentException("Missing parameters to run the script");

			if (targetDid == null)
				throw new IllegalArgumentException("Missing target user DID");

			if (targetAppDid == null)
				throw new IllegalArgumentException("Missing target application DID");

			if (resultType == null)
				throw new IllegalArgumentException("Missing result type");

			try {
				return controller.callScript(name, params, targetDid, targetAppDid, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	/**
	 * Executes a previously registered server side script with a direct URL
	 * where the values can be passed as part of the query.
	 * Vault owner or external users are allowed to call scripts on someone's vault.
	 *
	 * @param name	   The call's script name
	 * @param params	 The parameters for the script.
	 * @param targetDid  The script owner's user did.
	 * @param targetAppDid The script owner's application did.
	 * @param resultType String, byte[], JsonNode, Reader, Write, OutputStream, Reader, InputStream
	 * @param <T>		String, byte[], JsonNode, Reader, Write, OutputStream, Reader, InputStream
	 * @return 			 Result for specific script type
	 */
	public <T> CompletableFuture<T> callScriptUrl(String name,
											String params,
											String targetDid,
											String targetAppDid,
											Class<T> resultType) {

		return CompletableFuture.supplyAsync(()-> {
			if (name == null)
				throw new IllegalArgumentException("Missing script name.");

			if (params == null)
				throw new IllegalArgumentException("Missing parameters to run the script");

			if (targetDid == null)
				throw new IllegalArgumentException("Missing target user DID");

			if (targetAppDid == null)
				throw new IllegalArgumentException("Missing target application DID");

			if (resultType == null)
				throw new IllegalArgumentException("Missing result type");

			try {
				return controller.callScriptUrl(name, params, targetDid, targetAppDid, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	@Override
	public <T> CompletableFuture<T> downloadFile(String transactionId, Class<T> resultType) {
		return CompletableFuture.supplyAsync(()-> {
			try {
				if (transactionId == null)
					throw new IllegalArgumentException("Missing transactionId.");

				if (resultType == null)
					throw new IllegalArgumentException("Missing result type");

				return controller.downloadFile(transactionId, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	@Override
	public <T> CompletableFuture<T> uploadFile(String transactionId, Class<T> resultType) {
		return CompletableFuture.supplyAsync(()-> {
			try {
				if (transactionId == null)
					throw new IllegalArgumentException("Missing transactionId.");

				if (resultType == null)
					throw new IllegalArgumentException("Missing result type");

				return controller.uploadFile(transactionId, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}
}

==> hive-v2.6.1-sources.jar: org/elastos/hive/ScriptRunner.java <==
package org.elastos.hive;

import com.fasterxml.jackson.databind.JsonNode;

import org.elastos.hive.exception.HiveException;
import org.elastos.hive.service.ScriptingInvocationService;
import org.elastos.hive.vault.scripting.ScriptingController;

import java.security.InvalidParameterException;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.CompletionException;

/**
 * The script runner is used on the script calling side.
 *
 * <p>To call the script, the script owner need register the script first.</p>
 *
 * <pre>
 * 		Vault vault = new Vault(appContext, providerAddress);
 * 		ScriptingService scriptingService = vault.getScriptingService();
 * 		scriptingService.registerScript(...);
 * </pre>
 *
 * <p>Then the script caller can use this class to execute the script.</p>
 *
 * <pre>
 * 		ScriptRunner scriptRunner = new ScriptRunner(callerAppContext, providerAddress);
 * 		scriptRunner.callScript(...).get();
 * </pre>
 */
public class ScriptRunner extends ServiceEndpoint implements ScriptingInvocationService {
	private ScriptingController controller;

	public ScriptRunner(AppContext context, String providerAddress) {
		super(context, providerAddress);
		this.controller = new ScriptingController(this);
	}

	public ScriptRunner(AppContext context) {
		this(context, null);
	}

	@Override
	public <T> CompletableFuture<T> callScript(String name,
											JsonNode params,
											String targetDid,
											String targetAppDid,
											Class<T> resultType) {

		return CompletableFuture.supplyAsync(()-> {
			if (name == null)
				throw new IllegalArgumentException("Missing script name.");

			//if (params == null)
			//	throw new IllegalArgumentException("Missing parameters to run the script");

			if (targetDid == null)
				throw new IllegalArgumentException("Missing target user DID");

			if (targetAppDid == null)
				throw new IllegalArgumentException("Missing target application DID");

			if (resultType == null)
				throw new IllegalArgumentException("Missing result type");

			try {
				return controller.callScript(name, params, targetDid, targetAppDid, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	/**
	 * Executes a previously registered server side script with a direct URL
	 * where the values can be passed as part of the query.
	 * Vault owner or external users are allowed to call scripts on someone's vault.
	 *
	 * @param name	   The call's script name
	 * @param params	 The parameters for the script.
	 * @param targetDid  The script owner's user did.
	 * @param targetAppDid The script owner's application did.
	 * @param resultType String, byte[], JsonNode, Reader, Write, OutputStream, Reader, InputStream
	 * @param <T>		String, byte[], JsonNode, Reader, Write, OutputStream, Reader, InputStream
	 * @return 			 Result for specific script type
	 */
	public <T> CompletableFuture<T> callScriptUrl(String name,
											String params,
											String targetDid,
											String targetAppDid,
											Class<T> resultType) {

		return CompletableFuture.supplyAsync(()-> {
			if (name == null)
				throw new IllegalArgumentException("Missing script name.");

			if (params == null)
				throw new IllegalArgumentException("Missing parameters to run the script");

			if (targetDid == null)
				throw new IllegalArgumentException("Missing target user DID");

			if (targetAppDid == null)
				throw new IllegalArgumentException("Missing target application DID");

			if (resultType == null)
				throw new IllegalArgumentException("Missing result type");

			try {
				return controller.callScriptUrl(name, params, targetDid, targetAppDid, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	@Override
	public <T> CompletableFuture<T> uploadFile(String transactionId, Class<T> resultType) {
		return CompletableFuture.supplyAsync(()-> {
			try {
				if (transactionId == null)
					throw new IllegalArgumentException("Missing transactionId.");

				if (resultType == null)
					throw new IllegalArgumentException("Missing result type");

				return controller.uploadFile(transactionId, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	@Override
	public <T> CompletableFuture<T> downloadFile(String transactionId, Class<T> resultType) {
		return CompletableFuture.supplyAsync(()-> {
			try {
				if (transactionId == null)
					throw new IllegalArgumentException("Missing transactionId.");

				if (resultType == null)
					throw new IllegalArgumentException("Missing result type");

				return controller.downloadFile(transactionId, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}

	@Override
	public <T> CompletableFuture<T> downloadFileByHiveUrl(String hiveUrl, Class<T> resultType) {
		return CompletableFuture.supplyAsync(() -> {
			try {
				return controller.downloadFileByHiveUrl(hiveUrl, resultType);
			} catch (HiveException | RuntimeException e) {
				throw new CompletionException(e);
			}
		});
	}
}
